var indexSectionsWithContent =
{
  0: "_abcdefghiklmnopqrstuvw~",
  1: "cdfhiknopqruv",
  2: "s",
  3: "cfgikpstu",
  4: "_abcdefgiklmnopqrstuvw~",
  5: "bcdefiklmnoprstuv",
  6: "cefgilstu",
  7: "cdfikosuv",
  8: "klv",
  9: "_cdefiklpqstu",
  10: "bdgipstu"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "defines",
  10: "groups"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Macros",
  10: "Modules"
};

